@@ -5,7 +5,7 @@ use MooseX::FollowPBP;
 use Carp;
 use Sort::Versions;
 
-use version; our $VERSION = qv('0.0.3');
+use version; our $VERSION = qv('0.1.0');
 
 has 'default_version' => (
     is  => 'rw',
@@ -16,6 +16,7 @@ has 'function' => (
     is  => 'rw',
     isa => 'HashRef[CodeRef]',
     reader  => '_get_function',
+    writer  => 'set_function',
 );
 
 sub get_function {
@@ -38,6 +39,17 @@ sub get_function {
     return $function_lookup_ref->{$available_versions[-1]};
 }
 
+sub register{
+    my $self = shift;
+    my %functions_to_register = @_;
+    
+    my %function_lookup = %{$self->_get_function};
+    my @new_function_versions = keys %functions_to_register;
+    
+    @function_lookup{@new_function_versions} = @functions_to_register{@new_function_versions};
+    $self->set_function(\%function_lookup);
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -52,7 +64,7 @@ Versionify::Dispatch - A function dispatcher that respects versions, with fallba
 
 =head1 VERSION
 
-This document describes Versionify::Dispatch version 0.0.3
+This document describes Versionify::Dispatch version 0.1.0
 
 
 =head1 SYNOPSIS
@@ -66,6 +78,12 @@ This document describes Versionify::Dispatch version 0.0.3
         }
     );
     
+    $dispatcher->register({
+        1.8 => sub {
+            ...
+        }
+    });
+    
     $dispatcher->get_function($desired_version)->(@args);
 
 
@@ -108,6 +126,14 @@ will remove any existing mapping.>
 Sets the default version to be used when no version is explicitly set in
 the C<get_function> call.
 
+=item register
+
+    $dispatcher->register(\%function_mapping)
+
+Registers additional version -> function mappings. This does not remove existing
+mappings, except when a version conflict arises - the newly registered function
+takes precedence.
+
 =item get_function
 
     $return = $dispatcher->get_function($version)->(@args);
